import { history, Link } from 'umi';
import { useRef } from 'react';
import { Button, Modal, message, Popconfirm } from 'antd';
import { PlusOutlined } from '@ant-design/icons';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import PageTable from '@/components/PageTable';
import { getBannerList, deleteBanner } from '@/services/banner';
import moment from 'moment';

const formatterTime = (val) => {
  return val && val !== '-' ? moment(val).format('YYYY-MM-DD') : '-';
};
export default (props) => {
  const actionRef = useRef();
  const gotoEdit = (val) => {
    if (val) {
      history.push({ pathname: `Advertisement/edit.jsx`, data: val });
    } else {
      history.push(`Advertisement/edit.jsx`);
    }
  };

  const handleDelete = (e) => {
    deleteBanner(e).then((res) => {
      message.success('删除成功');
      actionRef.current.reload();
    });
  };
  const handleOK = (record, data) => {
    const title = record.status
      ? '您确定要将该banner状态变更为未发布吗? 变更后该banner将不在移动端显示'
      : '您确定要将该banner状态变更为发布吗? 发布后该banner可以在移动端显示';
    Modal.confirm({
      title: title,
      okText: '确认',
      cancelText: '取消',
      onOk() {
        updateNews(record.newsId, { ...record, status: record.status === 1 ? 0 : 1 })
          .then((res) => {
            message.success('操作成功');
            actionRef.current.reload();
          })
          .catch((err) => {
            message.error(err);
          });
      },
    });
  };

  const actions = () => [
    <Button key="add" type="primary" icon={<PlusOutlined />} onClick={() => gotoEdit()}>
      新增
    </Button>,
  ];
  const columns = [
    {
      title: '名称',
      key: 'title',
      dataIndex: 'title',
    },
    {
      title: '图片',
      key: 'thumb',
      dataIndex: 'thumb',
      render: (t) => <img width={110} src={t} alt="" />,
    },
    {
      title: '位置',
      key: 'position',
      dataIndex: 'position',
      render: (_, record) => {
        return record.position === 'index'
          ? '首次引导页'
          : record.position === 'appIndex'
            ? 'app启动页'
            : record.position === 'banner'
              ? '农户轮播图' : '农机手轮播图'
      },
    },
    {
      title: '排序',
      key: 'sortNo',
      dataIndex: 'sortNo',
    },
    {
      title: '创建时间',
      key: 'createDate',
      dataIndex: 'createDate',
      render: formatterTime,
    },
    {
      title: '状态',
      dataIndex: 'status',
      key: 'status',
      width: 100,
      render: (_, record) => {
        return record.status === 1 ? '发布' : '未发布';
      },
    },

    {
      title: '操作',
      valueType: 'option',
      key: 'option',
      ellipsis: true,
      width: 200,
      render: (_, record) => [
        <Button style={{ padding: 0 }} type="link" key={1} onClick={() => handleOK(record)}>
          {record.status === 0 ? '发布' : '取消发布'}
        </Button>,
        <Button style={{ padding: 0 }} type="link" key={2} onClick={() => gotoEdit(record)}>
          编辑
        </Button>,
        <Popconfirm
          key={3}
          title="您是否确认删除 ?"
          onConfirm={() => handleDelete(record.bannerId)}
          okText="确定"
          cancelText="取消"
        >
          <Button style={{ padding: 0 }} type="link">
            删除
          </Button>
        </Popconfirm>,
      ],
    },
  ];

  return (
    <PageHeaderWrapper>
      <PageTable
        columns={columns}
        request={getBannerList}
        rowKey="bannerId"
        search={false}
        options={false}
        toolBarRender={actions}
        actionRef={actionRef}
      />
    </PageHeaderWrapper>
  );
};
