import React, { useState, useEffect } from 'react';
import { Card, Form, Button, Select, message } from 'antd';
import ProCard from '@ant-design/pro-card';
import { getOrderDetail } from '@/services/order'
import { getMachineryList, getduty } from '@/services/machinery';
import { history } from 'umi';
import { getUserList } from '@/services/user';
import { addDispatch, getdispatchId, cancelDispatch } from '@/services/dispatch';

const FormItem = Form.Item;
const formItemLayout = { labelCol: { span: 6 }, wrapperCol: { span: 14 } };
const { Option } = Select;
const goBack = () => {
  history.goBack();
};
export default (props) => {
  const { location } = props;
  const { id } = location.query;
  const [dispatch, setDispatch] = useState();
  const [loading, setLoading] = useState(false);
  const [dispatchId, setDispatchId] = useState()
  const [machineryList, setMachineryList] = useState([]);
  const [userList, setUserList] = useState([])

  const [cancelLoading, setCancelLoading] = useState(false);

  const submit = () => {
    if (!dispatch.machineryId) {
      message.warning('请选择调度的农机');
      return
    }
    if (!dispatch.workerId) {
      message.warning('请选择农机手');
      return
    }
    setLoading(true)
    addDispatch(dispatch).then(res => {
      message.success('调度成功');
      setLoading(false);
      goBack()
    }).catch((err) => {
      setLoading(false);
      message.error(err.message || err);
    });
  };
  const changeMachinery = (e) => {
    getduty(e, { date: dispatch.appointmentDate.substr(0, 10) }).then((res => {
      if (res.length != 0) {
        message.info('该农机已调度请选择其他农机');
        setDispatch({ ...dispatch, machineryId: null })
      } else {
        setDispatch({ ...dispatch, machineryId: e })
      }
    }))
  }
  const changeUser = (e) => {
    setDispatch({ ...dispatch, workerId: e })
  }
  const onCancel = () => {
    setCancelLoading(true)
    cancelDispatch(dispatchId).then(() => {
      setCancelLoading(false)
      setDispatchId()
      setDispatch({ ...dispatch, machineryId: null, workerId: null })
      message.success('取消成功');
    }).catch((err) => {
      setCancelLoading(false);
      message.error(err.message || err);
    });
  }
  useEffect(() => {

    getOrderDetail(id).then((res) => {
      res.machineryId = null
      res.typeId = res.machineryType
      setDispatch(res)
      getMachineryList({ orgId: res.orgId, status: 1, typeId: res.typeId, pageSize: 999 }).then((res2) => {
        setMachineryList(res2.records)
      })
      getUserList({ org_id: res.orgId, pageSize: 999 }).then(res3 => {
        setUserList(res3.records)
      })
      if (res.dispatchStatus == 1) {
        getdispatchId(id).then(res4 => {
          setDispatchId(res4.dispatchId)
          setDispatch({ ...res, machineryId: res4.machineryId, workerId: res4.workerId })
        })
      }
    })
  }, [id])
  return (
    <Card>
      <ProCard tabs={{ type: 'card' }}>
        <ProCard.TabPane key={1} tab="订单调度">
          <Form {...formItemLayout}>
            <FormItem label="客户姓名">
              {dispatch?.personName}
            </FormItem>
            <FormItem label="联系电话">
              {dispatch?.phone}
            </FormItem>
            <FormItem label="预约地址">
              {dispatch?.address}
            </FormItem>
            <FormItem label="预约时间">
              {dispatch?.appointmentDate}
            </FormItem>
            <FormItem label="机构名">
              {dispatch?.orgName}
            </FormItem>
            <FormItem label="农机类型">
              {dispatch?.typeName}
            </FormItem>
            <FormItem label="农机">
              <Select placeholder="请选择" value={dispatch?.machineryId} onChange={changeMachinery} allowClear style={{ width: '350px' }}>
                {machineryList.map((item) => (
                  <Option value={item.machineryId} key={item.machineryId}>
                    {item.name}
                  </Option>
                ))}
              </Select>
            </FormItem>
            <FormItem label="农机手">
              <Select placeholder="请选择" value={dispatch?.workerId} onChange={changeUser} allowClear style={{ width: '350px' }}>
                {userList.map((item) => (
                  <Option value={item.userId} key={item.userId}>
                    {item.userName}
                  </Option>
                ))}
              </Select>
            </FormItem>
            <FormItem label=" " colon={false}>
              <Button type="default" onClick={() => goBack()}>
                返回
              </Button>
              {
                dispatchId ?
                  <Button loading={cancelLoading} onClick={onCancel} style={{ marginLeft: '4em' }}>
                    取消
                  </Button> :
                  <Button type="primary" loading={loading} onClick={submit} style={{ marginLeft: '4em' }}>
                    保存
                  </Button>
              }
            </FormItem>
          </Form>
        </ProCard.TabPane>
      </ProCard>
    </Card>
  );
};
